com.blockether.vis.contract.config

Vis configuration vocabulary and JSON Schema validation.

Vis configuration vocabulary and JSON Schema validation.
raw docstring

api-style-aliasesclj

Accepted provider API-style spelling to normalized runtime spelling.

Accepted provider API-style spelling to normalized runtime spelling.
sourceraw docstring

api-style-valuesclj

Documented provider API styles.

Documented provider API styles.
sourceraw docstring

config-explain-dataclj

(config-explain-data config)

JSON Schema errors for configuration, or nil.

JSON Schema errors for configuration, or nil.
sourceraw docstring

config-valid?clj

(config-valid? config)

True when the raw string-keyed configuration satisfies the contract schema.

True when the raw string-keyed configuration satisfies the contract schema.
sourceraw docstring

definition-property-namesclj

(definition-property-names definition)

Property names declared by one object definition in config.json.

Property names declared by one object definition in config.json.
sourceraw docstring

definition-valid?clj

(definition-valid? definition value)

True when raw JSON-shaped data satisfies one configuration definition.

True when raw JSON-shaped data satisfies one configuration definition.
sourceraw docstring

jail-environment-valuesclj

Sandbox environment modes.

Sandbox environment modes.
sourceraw docstring

titling-modesclj

Session title modes.

Session title modes.
sourceraw docstring

workspace-access-valuesclj

Accepted workspace access spellings.

Accepted workspace access spellings.
sourceraw docstring

workspace-draft-valuesclj

Workspace draft policies.

Workspace draft policies.
sourceraw docstring

workspace-os-valuesclj

Workspace host selectors.

Workspace host selectors.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries