Canonical content validation from JSON Schema.
Canonical content validation from JSON Schema.
(block-explain-data block)JSON Schema errors for an invalid canonical block, or nil.
JSON Schema errors for an invalid canonical block, or nil.
(block-valid? block)True when block satisfies the canonical block JSON Schema.
True when `block` satisfies the canonical block JSON Schema.
(event-valid? event)True when event satisfies the canonical content-event JSON Schema.
True when `event` satisfies the canonical content-event JSON Schema.
(message-explain-data message)JSON Schema errors for an invalid canonical message, or nil.
JSON Schema errors for an invalid canonical message, or nil.
(message-valid? message)True when message satisfies the canonical message JSON Schema and its timestamps are ordered.
True when `message` satisfies the canonical message JSON Schema and its timestamps are ordered.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |