Clojure only.

com.blockether.vis.contract.improve

Editable Improve records and immutable source links, validated by JSON Schema.

Editable Improve records and immutable source links, validated by JSON Schema.
raw docstring

valid?clj

(valid? definition value)

Validate a record, create/update input or list options using the canonical schema.

Validate a record, create/update input or list options using the canonical schema.
sourceraw docstring

validate!clj

(validate! definition value)

Return valid input or a sanitized client error without echoing private analysis.

Return valid input or a sanitized client error without echoing private analysis.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries