com.blockether.vis.contract.provider

Provider limits vocabulary and report validation from JSON Schema.

Provider limits vocabulary and report validation from JSON Schema.
raw docstring

explain-reportclj

(explain-report value)

JSON Schema errors for an invalid provider report, or nil.

JSON Schema errors for an invalid provider report, or nil.
sourceraw docstring

limit-row-valid?clj

(limit-row-valid? value)

True when value satisfies the provider limit-row schema.

True when `value` satisfies the provider limit-row schema.
sourceraw docstring

report-valid?clj

(report-valid? value)

True when value satisfies the provider report schema.

True when `value` satisfies the provider report schema.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries