com.blockether.vis.contract.toggle

Feature-toggle vocabulary and contribution validation from JSON Schema.

Feature-toggle vocabulary and contribution validation from JSON Schema.
raw docstring

boolean-false-tokensclj

Lower-case wire tokens that mean false.

Lower-case wire tokens that mean false.
sourceraw docstring

boolean-true-tokensclj

Lower-case wire tokens that mean true.

Lower-case wire tokens that mean true.
sourceraw docstring

config-truthy-tokensclj

Lower-case configuration strings that hydrate to true.

Lower-case configuration strings that hydrate to true.
sourceraw docstring

contribution-valid?clj

(contribution-valid? value)

True when value satisfies the toggle contribution schema and callback semantics.

True when `value` satisfies the toggle contribution schema and callback semantics.
sourceraw docstring

default-typeclj

Kind used when a contribution omits :type.

Kind used when a contribution omits `:type`.
sourceraw docstring

explain-contributionclj

(explain-contribution value)

JSON Schema errors for an invalid toggle contribution, or nil.

JSON Schema errors for an invalid toggle contribution, or nil.
sourceraw docstring

id-patternclj

Portable canonical toggle-id regular expression.

Portable canonical toggle-id regular expression.
sourceraw docstring

max-description-lengthclj

Maximum length of one settings-row description.

Maximum length of one settings-row description.
sourceraw docstring

settings-description?clj

(settings-description? value)

True for one non-blank settings-row line within the contract bound.

True for one non-blank settings-row line within the contract bound.
sourceraw docstring

toggle-id?clj

(toggle-id? value)

True only for canonical lower-case snake_case toggle ids.

True only for canonical lower-case snake_case toggle ids.
sourceraw docstring

typesclj

Closed feature-toggle kinds.

Closed feature-toggle kinds.
sourceraw docstring

versionclj

Feature-toggle contract document version.

Feature-toggle contract document version.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries