Activity vocabulary, declaration and bounded projection admission. Lifecycle stays in the engine.
Activity vocabulary, declaration and bounded projection admission. Lifecycle stays in the engine.
(from-wire value)Valid projection in engine spelling, or nil. Never accepts retired owner/view keys.
Valid projection in engine spelling, or nil. Never accepts retired owner/view keys.
(valid-presentation? value)Admit explicit headline/summary/content and non-nested sections, within one shared budget.
Admit explicit headline/summary/content and non-nested sections, within one shared budget.
(valid-projection? value)Admit the closed schema plus globally unique row ids and the canonical UTF-8 byte bound.
Admit the closed schema plus globally unique row ids and the canonical UTF-8 byte bound.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |