Vis configuration vocabulary and JSON Schema validation.
Vis configuration vocabulary and JSON Schema validation.
Accepted provider API-style spelling to normalized runtime spelling.
Accepted provider API-style spelling to normalized runtime spelling.
Documented provider API styles.
Documented provider API styles.
(config-explain-data config)JSON Schema errors for configuration, or nil.
JSON Schema errors for configuration, or nil.
(config-valid? config)True when the raw string-keyed configuration satisfies the contract schema.
True when the raw string-keyed configuration satisfies the contract schema.
(definition-property-names definition)Property names declared by one object definition in config.json.
Property names declared by one object definition in config.json.
(definition-valid? definition value)True when raw JSON-shaped data satisfies one configuration definition.
True when raw JSON-shaped data satisfies one configuration definition.
Accepted workspace access spellings.
Accepted workspace access spellings.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |