com.blockether.vis.contract.content

Canonical content validation from JSON Schema.

Canonical content validation from JSON Schema.
raw docstring

block-explain-dataclj

(block-explain-data block)

JSON Schema errors for an invalid canonical block, or nil.

JSON Schema errors for an invalid canonical block, or nil.
sourceraw docstring

block-valid?clj

(block-valid? block)

True when block satisfies the canonical block JSON Schema.

True when `block` satisfies the canonical block JSON Schema.
sourceraw docstring

event-valid?clj

(event-valid? event)

True when event satisfies the canonical content-event JSON Schema.

True when `event` satisfies the canonical content-event JSON Schema.
sourceraw docstring

message-explain-dataclj

(message-explain-data message)

JSON Schema errors for an invalid canonical message, or nil.

JSON Schema errors for an invalid canonical message, or nil.
sourceraw docstring

message-valid?clj

(message-valid? message)

True when message satisfies the canonical message JSON Schema and its timestamps are ordered.

True when `message` satisfies the canonical message JSON Schema and its timestamps are ordered.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries