Editable Improve records and immutable source links, validated by JSON Schema.
Editable Improve records and immutable source links, validated by JSON Schema.
(valid? definition value)Validate a record, create/update input or list options using the canonical schema.
Validate a record, create/update input or list options using the canonical schema.
(validate! definition value)Return valid input or a sanitized client error without echoing private analysis.
Return valid input or a sanitized client error without echoing private analysis.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |