Provider limits vocabulary and report validation from JSON Schema.
Provider limits vocabulary and report validation from JSON Schema.
(explain-report value)JSON Schema errors for an invalid provider report, or nil.
JSON Schema errors for an invalid provider report, or nil.
(limit-row-valid? value)True when value satisfies the provider limit-row schema.
True when `value` satisfies the provider limit-row schema.
How exactly a row's numbers are known.
How exactly a row's numbers are known.
(report-valid? value)True when value satisfies the provider report schema.
True when `value` satisfies the provider report schema.
What one limit row is measured against.
What one limit row is measured against.
Provider contract document version.
Provider contract document version.
Calendar units a row's window may use.
Calendar units a row's window may use.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |