Feature-toggle vocabulary and contribution validation from JSON Schema.
Feature-toggle vocabulary and contribution validation from JSON Schema.
Lower-case wire tokens that mean false.
Lower-case wire tokens that mean false.
Lower-case wire tokens that mean true.
Lower-case wire tokens that mean true.
Lower-case configuration strings that hydrate to true.
Lower-case configuration strings that hydrate to true.
(contribution-valid? value)True when value satisfies the toggle contribution schema and callback semantics.
True when `value` satisfies the toggle contribution schema and callback semantics.
Kind used when a contribution omits :type.
Kind used when a contribution omits `:type`.
(explain-contribution value)JSON Schema errors for an invalid toggle contribution, or nil.
JSON Schema errors for an invalid toggle contribution, or nil.
Portable canonical toggle-id regular expression.
Portable canonical toggle-id regular expression.
Maximum length of one settings-row description.
Maximum length of one settings-row description.
(settings-description? value)True for one non-blank settings-row line within the contract bound.
True for one non-blank settings-row line within the contract bound.
(toggle-id? value)True only for canonical lower-case snake_case toggle ids.
True only for canonical lower-case snake_case toggle ids.
Feature-toggle contract document version.
Feature-toggle contract document version.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |